==> v8.3.zip: ru_twords_ru_tw/bible/other/stronghold.md <==
# крепость, крепкий, укрепление, укрепленный, укреплять

## Определение:

Крепость (устар. — твердыня) — это хорошо обороняемое место, надёжно защищённое от вражеских атак. Укреплённым называется город или другое место, которое является безопасным при нападении врага.

* Крепостью может называться укреплённое здание, оборонительные стены или естественные преграды, такие как скалы или высокие горы.
* Люди укрепляли крепости, строя толстые стены или другие сооружения, из-за которых врагу было трудно прорваться.
* Слова “крепость” или “укрепление” можно перевести как “безопасное место”, “неприступное место” или “хорошо защищённое место”.
* Словосочетание “укреплённый город” можно перевести как “надёжно защищённый город”.
* Это слово может использоваться в переносном значении, когда речь идёт о Боге, Который является крепостью и укрытием для тех, кто Ему доверяет. (См.: [Metaphor](rc://*/ta/man/translate/figs-metaphor))
* У слов “крепость” и “твердыня” есть ещё одно переносное значение. Когда человек упорствует в чём-то  ошибочном, например,  в поклонении ложным богам или чему-то другому, когда упорно придерживается какой-то ложной идее, про него можно сказать, что в голове у такого человека твердыня.
* В этом случае слово “твердыня” нельзя переводить как “убежище”. Следует подобрать соответствующее слово целевого языка с негативным оттенком.

(См. также: [ложный бог](../kt/falsegod.md), [убежище](../other/refuge.md), [Яхве](../kt/yahweh.md))

## Ссылки на библейский текст:

* [2 Кор. 10:3-4](rc://*/tn/help/2co/10/03)
* [4 Цар. 8:10-12](rc://*/tn/help/2ki/08/10)
* [2 Цар. 5:8-10](rc://*/tn/help/2sa/05/08)
* [Деян. 21:34-36](rc://*/tn/help/act/21/34)
* [Авв. 1:10-11](rc://*/tn/help/hab/01/10)

## Данные о слове:

* Номера Стронга: H490, H553, H759, H1001, H1002, H1003, H1219, H1225, H2388, H4013, H4026, H4581, H4526, H4679, H4685, H4686, H4692, H4693, H4694, H4869, H5794, H5797, H5800, H6438, H6696, H6877, H7682, G3794, G3925

==> v9.2.zip: ru_twords_ru_tw/bible/other/stronghold.md <==
# крепость, крепкий, укрепление, укрепленный, укреплять

## Определение:

Крепость (устар. — твердыня) — это хорошо обороняемое место, надёжно защищённое от вражеских атак. Укреплённым называется город или другое место, которое является безопасным при нападении врага.
* Крепостью может называться укреплённое здание, оборонительные стены или естественные преграды, такие как скалы или высокие горы.
* Люди укрепляли крепости, строя толстые стены или другие сооружения, из-за которых врагу было трудно прорваться.
* Слова “крепость” или “укрепление” можно перевести как “безопасное место”, “неприступное место” или “хорошо защищённое место”.
* Словосочетание “укреплённый город” можно перевести как “надёжно защищённый город”.
* Это слово может использоваться в переносном значении, когда речь идёт о Боге, Который является крепостью и укрытием для тех, кто Ему доверяет. (См.: [Metaphor](rc://ru/ta/man/translate/figs-metaphor))
* У слов “крепость” и “твердыня” есть ещё одно переносное значение. Когда человек упорствует в чём-то  ошибочном, например,  в поклонении ложным богам или чему-то другому, когда упорно придерживается какой-то ложной идее, про него можно сказать, что в голове у такого человека твердыня.
* В этом случае слово “твердыня” нельзя переводить как “убежище”. Следует подобрать соответствующее слово целевого языка с негативным оттенком.

(См. также: [ложный бог](../kt/falsegod.md), [убежище](../other/refuge.md), [Яхве](../kt/yahweh.md))

## Ссылки на библейский текст:

* [2 Кор. 10:3-4](rc://ru/tn/help/2co/10/03)
* [4 Цар. 8:10-12](rc://ru/tn/help/2ki/08/10)
* [2 Цар. 5:8-10](rc://ru/tn/help/2sa/05/08)
* [Деян. 21:34-36](rc://ru/tn/help/act/21/34)
* [Авв. 1:10-11](rc://ru/tn/help/hab/01/10)

## Данные о слове:

* Номера Стронга: H490, H553, H759, H1001, H1002, H1003, H1219, H1225, H2388, H4013, H4026, H4581, H4526, H4679, H4685, H4686, H4692, H4693, H4694, H4869, H5794, H5797, H5800, H6438, H6696, H6877, H7682, G3794, G3925
